@@ -65,7 +65,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
     def get_fields_to_return(self) -> T.Set[str]:
         """Include nested fields with DOT notation"""
         if self._fields_to_return is None:
-            return {*self._node.__fields__.keys(), *self._fields_to_include}
+            return {*self.get_aliases(), *self._fields_to_include}
         return self._fields_to_return
 
     @property
@@ -110,21 +110,31 @@ class Resolver(BaseModel, T.Generic[NodeType]):
     """SETTERS"""
 
     def fields_to_return(
-        self: ThisResolverType, fields_to_return: T.Set[str]
+        self: ThisResolverType, *fields_to_return: str
     ) -> ThisResolverType:
-        self._fields_to_return = fields_to_return
+        self._fields_to_return = set(fields_to_return)
         return self
 
     def include_fields(
-        self: ThisResolverType, fields_to_include: T.Set[str]
+        self: ThisResolverType, *fields_to_include: str
     ) -> ThisResolverType:
-        self._fields_to_include.update(fields_to_include)
+        self._fields_to_include.update(set(fields_to_include))
+        return self
+
+    def exclude_fields(
+        self: ThisResolverType, *fields_to_exclude: str
+    ) -> ThisResolverType:
+        self._fields_to_include = self._fields_to_include - set(fields_to_exclude)
         return self
 
     def include_computed_fields(self: ThisResolverType) -> ThisResolverType:
         self._fields_to_include.update(self._node._computed_properties)
         return self
 
+    def include_appendix_fields(self: ThisResolverType) -> ThisResolverType:
+        self._fields_to_include.update(self._node._appendix_properties)
+        return self
+
     @staticmethod
     def validate_no_intersections_helper(
         set_a: T.Set = None, set_b: T.Set = None
@@ -379,12 +389,18 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             raise ResolverException(f"No {self._model_name} in db with fields {kwargs}")
         return model
 
+    @classmethod
+    def get_aliases(cls: T.Type[ThisResolverType]) -> T.Set[str]:
+        node = cls._node
+        return {field.alias for field in node.__fields__.values()}
+
     def parse_nested_obj(
         self, raw_d: dict, error_for_extra_fields: bool = False
     ) -> NodeType:
         node: NodeType = self._node.parse_obj(raw_d)
         # pass on other fields as an "extra" dict
-        other_fields = set(raw_d.keys()) - set(node.__fields__.keys())
+        # problem with this is aliases are currently also added to extra... do i want this?
+        other_fields = set(raw_d.keys()) - self.get_aliases()
         for field_name in other_fields:
             resolver: Resolver = self._nested_resolvers.get(field_name)
             if resolver is None:
